require_relative 'player'
require_relative 'die'
require_relative 'game_turn'
require_relative 'treasure_trove'

module StudioGame
	class Game
	attr_reader :title

	def initialize(title)
		@title = title
		@players = []
	end

	def add_player(player)
		@players << player
	end

	def load_players(file)
		File.readlines(file).each do |line|
			add_player(Player.from_csv(line))
		end
	end

	def save_high_score(to_file = 'high_scores.txt')
		File.open(to_file, "w") do |file|
			sorted_players = @players.sort
			file.puts "\n#{@title} High scores:"
			sorted_players.each do |player|
				file.puts player.format_score(player)
			end
		end
	end

	def play(rounds)
		puts "There are #{@players.size} in #{@title}:"

		@players.each do |player|
			puts player
		end
		puts "\n"
		treasures = TreasureTrove::TREASURES

        puts "There are #{treasures.size} treasures to be found:"
		treasures.each do |treasure|
			puts "A #{treasure.name} is worth #{treasure.points} points."
		end

		1.upto(rounds) do |round|
			puts "\nRound: #{round}"
		  	@players.each do |player|
			  GameTurn.take_turn(player)
		    end
		end
	end



	def print_name_and_health(player)
		puts "#{player.name}: #{player.health}"
	end

	def print_stats
		strong_players, wimpy_players = @players.partition { |p| p.strong?}

		puts "\n#{@title} statistics:"

		puts "\n#{strong_players.size} strong players:"
		strong_players.each do |player|
			print_name_and_health(player)
		end

		puts "\n#{wimpy_players.size} wimpy players:"
		wimpy_players.each do |player|
			print_name_and_health(player)
		end
		puts "\n"
		treasure_details
		high_score
	end

	def treasure_details
		@players.each do |player|
			puts "\n#{player.name}'s points total:"
			player.each_found_treasure do |treasure|
				puts "#{treasure.points} total #{treasure.name} points."
			end
			grand_total(player)
		end
	end

	def grand_total(player)
	  puts "#{player.points} grand total points"
	end



	def high_score
		sorted_players = @players.sort
		puts sorted_players
		puts "\n#{@title} High scores:"
		sorted_players.each do |player|
			puts player.format_score(player)
		end
	end
end
end



