require_relative 'treasure_trove'
require_relative 'playable'

module StudioGame
	class Player
		include Playable

		attr_reader	:health
		attr_accessor :name

		def initialize(name, health = 100)
			@name = name.capitalize
			@health = health
			@found_treasures = Hash.new(0)
		end

		def to_s
			"\nI'm #{@name} with a health = #{@health}, points = #{points} and score = #{score}"
		end

		def score
			@health + points
		end

		def format_score(player)
			"#{player.name.ljust(20, '.')}#{player.score}"
		end

		def <=>(other)
			other.score <=> score
		end

		def self.from_csv(line)
			name, health = line.split(',')
			Player.new(name, Integer(health))
		end

		def found_treasure(treasure)
			@found_treasures[treasure.name] += treasure.points
			puts "#{@name} got a #{treasure.name} that is worth #{treasure.points} points."
			puts "#{@name}'s treasures #{@found_treasures}"
		end

		def points
			@found_treasures.values.reduce(0, :+)
		end

		def each_found_treasure
			@found_treasures.each do |name, points|
				yield Treasure.new(name, points)
			end
		end

	end

	if  __FILE__ == $0
	  player1 = Player.new("moe")
	  player2 = Player.new("larry", 60)
	  player3 = Player.new("curly", 125)

	  puts player1
	  puts player2
	  puts player3
    end
end
